package cn.estsh.i3plus.pojo.wms.bean;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : 库存移动单处理成功后的记录，通过监听交易成功队列写入
 * @Reference :
 * @Author : Rock.Yu
 * @CreateDate : 2019-06-20 14:09
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name = "WMS_MOVE_TO_ERP", indexes = {
        @Index(columnList = "TRANS_TYPE_CODE"),
        @Index(columnList = "ORDER_NO"),
        @Index(columnList = "ITEM"),
        @Index(columnList = "ORGANIZE_CODE"),
        @Index(columnList = "PART_NO")
})
@Api("库存移动单主表信息")
public class WmsMoveToERP extends BaseBean {

    private static final long serialVersionUID = -6223527594941733060L;
    @Column(name = "ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    /**
     * 状态:1=创建,10=待处理,20=已处理
     */
    @Column(name = "ORDER_STATUS")
    @ApiParam(value = "状态", example = "0")
    public Integer orderStatus;

    @Column(name = "REMARK")
    @ApiParam("备注")
    public String remark;

    @Column(name = "TRANS_TYPE_CODE")
    @ApiParam(value = "交易类型代码")
    private String transTypeCode;

    @Column(name = "ERROR_MESSAGE")
    @ApiParam(value = "错误信息")
    private String errorMessage;

    @Column(name="IS_URGENT")
    @ApiParam(value = "是否紧急", example = "0")
    public Integer isUrgent;

    @Column(name = "CAR_NO")
    @ApiParam(value = "车牌号")
    private String carNo;

    @Column(name="ITEM")
    @ApiParam(value = "行号")
    public String item;

    @Column(name="PART_NO")
    @ApiParam("物料编码")
    public String partNo;

    @Column(name="PART_NAME_RDD")
    @ApiParam("物料名称")
    public String partNameRdd;

    @Column(name="VENDOR_NO")
    @ApiParam("供应商编号")
    public String vendorNo;

    @Column(name="CUST_NO")
    @ApiParam("客户编号")
    public String custNo;

    @Column(name="TRANS_QTY", columnDefinition = "decimal(18,8)")
    @ApiParam(value = "处理数量", example = "0")
    public Double transQty;

    @Column(name="REJECT_QTY", columnDefinition = "decimal(18,8)")
    @ApiParam(value = "不合格处理数量", example = "0")
    public Double rejectQty;

    @Column(name="UNIT")
    @ApiParam("单位")
    public String unit;

    @Column(name="SRC_WH_NO")
    @ApiParam("源仓库代码")
    public String srcWhNo;

    @Column(name="SRC_ZONE_NO")
    @ApiParam("源存储区代码")
    public String srcZoneNo;

    @Column(name="SRC_LOCATE_NO")
    @ApiParam("源库位代码")
    public String srcLocateNo;

    @Column(name="DEST_WH_NO")
    @ApiParam("目标仓库代码")
    public String destWhNo;

    @Column(name="DEST_ZONE_NO")
    @ApiParam("目标存储区代码")
    public String destZoneNo;

    @Column(name="DEST_LOCATE_NO")
    @ApiParam("目标库位代码")
    public String destLocateNo;

    /**
     * 状态:1=创建,10=待处理,20=已处理
     */
    @Column(name="ITEM_STATUS")
    @ApiParam(value = "状态", example = "0")
    public Integer itemStatus;

    /**
     * ASN,PO,SO
     */
    @Column(name="REF_TYPE")
    @ApiParam("关联单据类型")
    public String refType;

    @Column(name="REF_SRC")
    @ApiParam("关联单号")
    public String refSrc;

    @Column(name="REF_UNIT")
    @ApiParam("关联单位")
    public String refUnit;

    @Column(name="REF_QTY", columnDefinition = "decimal(18,8)")
    @ApiParam("关联数量")
    public Double refQty;

    @Column(name = "SRC_AREA_NO")
    @ApiParam("来源库存地")
    public String srcAreaNo;

    @Column(name = "DEST_AREA_NO")
    @ApiParam("目标库存地")
    public String destAreaNo;

    @Column(name = "BUSI_TYPE_CODE")
    @ApiParam("交易类型")
    public Integer busiTypeCode;

    @Column(name = "IS_SYNC", nullable = false)
    @ApiParam("是否同步")
    public Integer isSync = CommonEnumUtil.FALSE;

    @Column(name="REF_ITEM")
    @ApiParam("关联单据行号")
    public String refItem;

    @Column(name="IS_LOCK")
    @ApiParam(value = "是否锁定", example = "2")
    public Integer isLock= CommonEnumUtil.FALSE;

    @Column(name = "YEAR")
    @ApiParam("年度")
    public String year;

    @ApiParam(value = "待出库数量", example = "0")
    @Transient
    private Long waitingCounts;

    @ApiParam(value = "已出库数量", example = "0")
    @Transient
    private Long finishedCounts;

    @Transient
    private Long shippingId;

    @Transient
    private Double transQtySum;

    public Double getTransQtySumVal() {
        return this.transQtySum == null ? 0 : this.transQtySum.doubleValue();
    }

    public Double getRejectQty(){
        return this.rejectQty == null ? 0 : this.rejectQty.doubleValue();
    }

    public Double getTransQty(){
        return this.transQty == null ? 0 : this.transQty.doubleValue();
    }

    public Long getWaitingCounts() {
        return waitingCounts == null ? 0L : this.waitingCounts;
    }

    public Long getFinishedCounts() {
        return finishedCounts == null ? 0L : this.finishedCounts;
    }

    public WmsMoveToERP() {}

    public WmsMoveToERP(String partNo, String partNameRdd, String vendorNo, String unit, String destAreaNo, Double transQtySum) {
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.vendorNo = vendorNo;
        this.unit = unit;
        this.destAreaNo = destAreaNo;
        this.transQtySum = transQtySum;
    }
}
